@@ -1749,7 +1749,12 @@ int mtp_progress (uint64_t const sent, uint64_t const total, void const * const
 			filetype == LIBMTP_FILETYPE_OGG ||
 			filetype == LIBMTP_FILETYPE_AUDIBLE ||
 			filetype == LIBMTP_FILETYPE_MP4 ||
-			filetype == LIBMTP_FILETYPE_UNDEF_AUDIO
+			filetype == LIBMTP_FILETYPE_UNDEF_AUDIO ||
+      filetype == LIBMTP_FILETYPE_AAC ||
+      filetype == LIBMTP_FILETYPE_MEDIACARD ||
+      filetype == LIBMTP_FILETYPE_FLAC ||
+      filetype == LIBMTP_FILETYPE_MP2 ||
+      filetype == LIBMTP_FILETYPE_M4A
 			)
 		return YES;
 	else
