@@ -30,7 +30,7 @@
 		[self setYear:0];
 		[self setFilesize:0];
 		[self setLength:0];
-		[self setCodec:CODEC_UNDEFINED];
+		[self setFileType:LIBMTP_FILETYPE_UNDEF_AUDIO];
 	}
 	return self;
 }
@@ -184,47 +184,12 @@
 	trackNumber = newTrackNumber;
 }
 
-- (codecTypes)codec
-{
-	return codec;
-}
-
 - (NSString *)njbCodec
 {
-	// is this a sensible default?
-	if (codec == CODEC_UNDEFINED)
+	// is this a sensible default? we should probably set all other than WMA/WAV to MP3
+	if (fileType == LIBMTP_FILETYPE_UNDEF_AUDIO || fileType == LIBMTP_FILETYPE_UNKNOWN)
 		return @"MP3";
-	return [self codecString];
-}
-
-- (NSString *)codecString
-{
-	switch (codec)
-	{
-		case CODEC_UNDEFINED:
-			return @"UNKNOWN";
-			break;
-	  case CODEC_MP3:
-			return @"MP3";
-			break;
-		case CODEC_WMA:
-			return @"WMA";
-			break;
-		case CODEC_WAV:
-			return @"WAV";
-			break;
-		case CODEC_AA:
-			return @"AA";
-			break;
-		default:
-			NSLog(@"Invalid codec in codecString, title %@", title);
-			return nil;
-	}
-}
-
-- (void)setCodec:(codecTypes)newCodec
-{
-	codec = newCodec;
+	return [self fileTypeString];
 }
 
 - (unsigned long long)filesize
@@ -266,15 +231,15 @@
 	[self setYear:[track year]];
 	[self setFilesize:[track filesize]];
 	[self setLength:[track length]];
-	[self setCodec:[track codec]];
+	[self setFileType:[track fileType]];
 	[self setItemID:[track itemID]];
 }
 
 - (NSString *)description
 {
-	return [NSString stringWithFormat:@"Title: %@, Artist: %@, Album: %@, Genre: %@, Length: %@, Track No: %d, Codec: %@, Filesize: %@, Track ID: %d, Year: %d, Filename: %@, Fullpath: %@",
+	return [NSString stringWithFormat:@"Title: %@, Artist: %@, Album: %@, Genre: %@, Length: %@, Track No: %d, File Type: %@, Filesize: %@, Track ID: %d, Year: %d, Filename: %@, Fullpath: %@",
 		title, artist, album, genre, [self lengthString], trackNumber,
-		[self codecString], [self filesizeString], itemID, year, filename, fullPath];
+		[self fileTypeString], [self filesizeString], itemID, year, filename, fullPath];
 }
 
 /* searches title, album, artist and genre for the string
@@ -317,4 +282,11 @@
 		return NSOrderedDescending;
 }
 
+/* gets the filetype from the extension of fullPath
+ */
+- (void)fileTypeFromExtension
+{
+	[self fileTypeFromExtension:fullPath];
+}
+
 @end
